==> 1.0.0.tar.gz: ios/Classes/YodosdkPlugin.swift <==
import Flutter
import Yodo1MasCore
import UIKit

public class YodosdkPlugin: NSObject, FlutterPlugin {
    var interstitialAd: Yodo1MasInterstitialAd!

  public static func register(with registrar: FlutterPluginRegistrar) {
    let channel = FlutterMethodChannel(name: "yodosdk", binaryMessenger: registrar.messenger())
    let interChannel = FlutterMethodChannel(name: "interChannel", binaryMessenger: registrar.messenger())
    let rewardChannel = FlutterMethodChannel(name: "rewardChannel", binaryMessenger: registrar.messenger())
    let instance = YodosdkPlugin()
      // Native
      let native:NativeAdFactory =  NativeAdFactory(messenger:  registrar.messenger())!
      registrar.register(native, withId: "nativeAd")
      //Banner
      let banner:BannerAdFactory =  BannerAdFactory(messenger:  registrar.messenger())!
      registrar.register(banner, withId: "bannerAd")
      YodoHelper._sink = channel
      InterHandler._sink = interChannel
      RewardHandler._sink = rewardChannel
      
    registrar.addMethodCallDelegate(instance, channel: channel)
  }

    
    public func interInit(){
        interstitialAd = Yodo1MasInterstitialAd.sharedInstance()
        interstitialAd.autoDelayIfLoadFail = true
        interstitialAd.adDelegate = self
        interstitialAd.load()
    }
    
    public func rewardInit(){
        let rewardAd = Yodo1MasRewardAd.sharedInstance()
        rewardAd.autoDelayIfLoadFail = true
        rewardAd.adDelegate = self
        rewardAd.load()
    }
    
    public func rewardInterInit(){
        let rewardedInterstitialAd = Yodo1MasRewardedInterstitialAd.sharedInstance()
        rewardedInterstitialAd.autoDelayIfLoadFail = true;
        rewardedInterstitialAd.adDelegate = self
        rewardedInterstitialAd.load()
       
    }
  public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
       result("iOS " + UIDevice.current.systemVersion)
        let args = call.arguments as? Dictionary<String, Any>
     
      if(call.method == "initSDK"){
          let showPrivacy = args?["showPrivacyDialog"] ?? true
          if(showPrivacy) as! Bool{
            YodoHelper.showDialog()
          }
          if let appId = args?["appId"]  {
              YodoHelper.initSdk(appId: appId as! String) {
                  let preLoad = args?["preLoadAds"] ?? false
                  if(preLoad) as! Bool{
                      self.interInit()
                      self.rewardInit()
                      self.rewardInterInit()
                  }
              }
          }
          return;
      }
      if(call.method == "showPrivacyDialog"){
          YodoHelper.showDialog()
          return;
      }
      if(call.method == "loadInter"){
          interInit()
          if(interstitialAd.isLoaded()){
             interstitialAd.show(withPlacement: "IosSdk")
          }else{
             interstitialAd.loadAndShow(withPlacement: "IosSdk")
          }
          return;
      }
      if(call.method == "loadReward"){
          rewardInit()
          let reward = Yodo1MasRewardAd.sharedInstance()
          if(reward.isLoaded()){
              reward.show(withPlacement: "IosSdk")
          }else{
              reward.loadAndShow(withPlacement: "IosSdk")
          }
          return;
      }
      
      if(call.method == "loadInterReward"){
          
          rewardInterInit()
          let rewardedInterstitialAd = Yodo1MasRewardedInterstitialAd.sharedInstance()
          if(rewardedInterstitialAd.isLoaded()){
              rewardedInterstitialAd.show(withPlacement: "IosSdk")
          }else{
              rewardedInterstitialAd.loadAndShow(withPlacement: "IosSdk")
          }
          return;
      }
  }
}

// For Reward

extension YodosdkPlugin: Yodo1MasRewardedInterstitialAdDelegate {
    public func onRewardedInterstitialAdLoaded(_ ad: Yodo1MasRewardedInterstitialAd) {
      RewardHandler._sink?.invokeMethod("loaded_reward_inter", arguments:ad.adPlacement)
    }
    public func onRewardedInterstitialAdFailed(toLoad ad: Yodo1MasRewardedInterstitialAd, withError error: Yodo1MasError) {
        ad.load()
        RewardHandler._sink?.invokeMethod("fail_load_reward_inter", arguments:error.getJsonObject())
    }
    public func onRewardedInterstitialAdOpened(_ ad: Yodo1MasRewardedInterstitialAd) {
        RewardHandler._sink?.invokeMethod("open_reward_inter", arguments:ad.adPlacement)
    }
    public func onRewardedInterstitialAdFailed(toOpen ad: Yodo1MasRewardedInterstitialAd, withError error: Yodo1MasError) {
        RewardHandler._sink?.invokeMethod("fail_open_reward_inter", arguments:error.getJsonObject())
     }
    public func onRewardedInterstitialAdClosed(_ ad: Yodo1MasRewardedInterstitialAd) {
        ad.load()
        RewardHandler._sink?.invokeMethod("close_reward_inter", arguments:ad.adPlacement)
     }
    public func onRewardedInterstitialAdEarned(_ ad: Yodo1MasRewardedInterstitialAd) {
        RewardHandler._sink?.invokeMethod("rewarded_reward_inter", arguments:ad.adPlacement)
   }
}


// For Reward

extension YodosdkPlugin: Yodo1MasRewardDelegate {
    public func onRewardAdLoaded(_ ad: Yodo1MasRewardAd) {
      RewardHandler._sink?.invokeMethod("loaded_reward", arguments:ad.adPlacement)
    }
    public func onRewardAdFailed(toLoad ad: Yodo1MasRewardAd, withError error: Yodo1MasError) {
        ad.load()
        RewardHandler._sink?.invokeMethod("fail_load_reward", arguments:error.getJsonObject())
    }
    public func onRewardAdOpened(_ ad: Yodo1MasRewardAd) {
        RewardHandler._sink?.invokeMethod("open_reward", arguments:ad.adPlacement)
    }
    public func onRewardAdFailed(toOpen ad: Yodo1MasRewardAd, withError error: Yodo1MasError) {
        RewardHandler._sink?.invokeMethod("fail_open_reward", arguments:error.getJsonObject())
     }
    public func onRewardAdClosed(_ ad: Yodo1MasRewardAd) {
        ad.load()
        RewardHandler._sink?.invokeMethod("close_reward", arguments:ad.adPlacement)
     }
    public func onRewardAdEarned(_ ad: Yodo1MasRewardAd) {
        RewardHandler._sink?.invokeMethod("rewarded_reward", arguments:ad.adPlacement)
   }
}

// For Inter
extension YodosdkPlugin: Yodo1MasInterstitialDelegate {
    // MARK: Yodo1MasInterstitialDelegate
    public func onInterstitialAdLoaded(_ ad: Yodo1MasInterstitialAd) {
        print("Loaded")
        InterHandler._sink?.invokeMethod("loaded_inter", arguments:ad.adPlacement)
    }
    
    public func onInterstitialAdFailed(toLoad ad: Yodo1MasInterstitialAd, withError error: Yodo1MasError) {
        print("AdFailed")
        ad.load()
        InterHandler._sink?.invokeMethod("failed_load_inter",  arguments:ad.adPlacement)
    }
    
    public func onInterstitialAdOpened(_ ad: Yodo1MasInterstitialAd) {
        print("OnAd Open")
        InterHandler._sink?.invokeMethod("open_inter",  arguments:ad.adPlacement)
    }
    
    public func onInterstitialAdFailed(toOpen ad: Yodo1MasInterstitialAd, withError error: Yodo1MasError) {
       
        print("On Failed")
        InterHandler._sink?.invokeMethod("failed_open_inter",  arguments:ad.adPlacement)
    }
    
    public func onInterstitialAdClosed(_ ad: Yodo1MasInterstitialAd) {
        ad.load()
        print("On AdClose")
        InterHandler._sink?.invokeMethod("close_inter", arguments:  ad.adPlacement)
    }
    
}

==> 1.0.6.tar.gz: ios/Classes/YodosdkPlugin.swift <==
import Flutter
import Yodo1MasCore
import UIKit

public class YodosdkPlugin: NSObject, FlutterPlugin {
    var interstitialAd: Yodo1MasInterstitialAd!

  public static func register(with registrar: FlutterPluginRegistrar) {
    let channel = FlutterMethodChannel(name: "yodosdk", binaryMessenger: registrar.messenger())
    let interChannel = FlutterMethodChannel(name: "interChannel", binaryMessenger: registrar.messenger())
    let rewardChannel = FlutterMethodChannel(name: "rewardChannel", binaryMessenger: registrar.messenger())
    let instance = YodosdkPlugin()
      // Native
      let native:NativeAdFactory =  NativeAdFactory(messenger:  registrar.messenger())!
      registrar.register(native, withId: "nativeAd")
      //Banner
      let banner:BannerAdFactory =  BannerAdFactory(messenger:  registrar.messenger())!
      registrar.register(banner, withId: "bannerAd")
      YodoHelper._sink = channel
      InterHandler._sink = interChannel
      RewardHandler._sink = rewardChannel
      
    registrar.addMethodCallDelegate(instance, channel: channel)
  }

    
    public func interInit(){
        interstitialAd = Yodo1MasInterstitialAd.sharedInstance()
        interstitialAd.autoDelayIfLoadFail = true
        interstitialAd.adDelegate = self
        interstitialAd.load()
    }
    
    public func rewardInit(){
        let rewardAd = Yodo1MasRewardAd.sharedInstance()
        rewardAd.autoDelayIfLoadFail = true
        rewardAd.adDelegate = self
        rewardAd.load()
    }
    
    public func rewardInterInit(){
        let rewardedInterstitialAd = Yodo1MasRewardedInterstitialAd.sharedInstance()
        rewardedInterstitialAd.autoDelayIfLoadFail = true;
        rewardedInterstitialAd.adDelegate = self
        rewardedInterstitialAd.load()
       
    }
  public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
       result("iOS " + UIDevice.current.systemVersion)
        let args = call.arguments as? Dictionary<String, Any>
     
      if(call.method == "initSDK"){
          let showPrivacy = args?["showPrivacyDialog"] ?? true
        
          Yodo1Mas.sharedInstance().isCOPPAAgeRestricted = false
          Yodo1Mas.sharedInstance().isGDPRUserConsent = true
          Yodo1Mas.sharedInstance().isCCPADoNotSell = false
//          if(showPrivacy) as! Bool{
//            YodoHelper.showDialog()
//          }
          if let appId = args?["appId"]  {
              YodoHelper.initSdk(appId: appId as! String) {
                  let preLoad = args?["preLoadAds"] ?? false
                  if(preLoad) as! Bool{
                      self.interInit()
                      self.rewardInit()
                      self.rewardInterInit()
                  }
              }
          }
          return;
      }
      if(call.method == "showPrivacyDialog"){
          YodoHelper.showDialog()
          return;
      }
      if(call.method == "loadInter"){
          interInit()
          if(interstitialAd.isLoaded()){
             interstitialAd.show(withPlacement: "IosSdk")
          }else{
             interstitialAd.loadAndShow(withPlacement: "IosSdk")
          }
          return;
      }
      if(call.method == "loadReward"){
          rewardInit()
          let reward = Yodo1MasRewardAd.sharedInstance()
          if(reward.isLoaded()){
              reward.show(withPlacement: "IosSdk")
          }else{
              reward.loadAndShow(withPlacement: "IosSdk")
          }
          return;
      }
      
      if(call.method == "loadInterReward"){
          
          rewardInterInit()
          let rewardedInterstitialAd = Yodo1MasRewardedInterstitialAd.sharedInstance()
          if(rewardedInterstitialAd.isLoaded()){
              rewardedInterstitialAd.show(withPlacement: "IosSdk")
          }else{
              rewardedInterstitialAd.loadAndShow(withPlacement: "IosSdk")
          }
          return;
      }
  }
}

// For Reward

extension YodosdkPlugin: Yodo1MasRewardedInterstitialAdDelegate {
    public func onRewardedInterstitialAdLoaded(_ ad: Yodo1MasRewardedInterstitialAd) {
      RewardHandler._sink?.invokeMethod("loaded_reward_inter", arguments:ad.adPlacement)
    }
    public func onRewardedInterstitialAdFailed(toLoad ad: Yodo1MasRewardedInterstitialAd, withError error: Yodo1MasError) {
        ad.load()
        RewardHandler._sink?.invokeMethod("fail_load_reward_inter", arguments:error.getJsonObject())
    }
    public func onRewardedInterstitialAdOpened(_ ad: Yodo1MasRewardedInterstitialAd) {
        RewardHandler._sink?.invokeMethod("open_reward_inter", arguments:ad.adPlacement)
    }
    public func onRewardedInterstitialAdFailed(toOpen ad: Yodo1MasRewardedInterstitialAd, withError error: Yodo1MasError) {
        RewardHandler._sink?.invokeMethod("fail_open_reward_inter", arguments:error.getJsonObject())
     }
    public func onRewardedInterstitialAdClosed(_ ad: Yodo1MasRewardedInterstitialAd) {
        ad.load()
        RewardHandler._sink?.invokeMethod("close_reward_inter", arguments:ad.adPlacement)
     }
    public func onRewardedInterstitialAdEarned(_ ad: Yodo1MasRewardedInterstitialAd) {
        RewardHandler._sink?.invokeMethod("rewarded_reward_inter", arguments:ad.adPlacement)
   }
}


// For Reward

extension YodosdkPlugin: Yodo1MasRewardDelegate {
    public func onRewardAdLoaded(_ ad: Yodo1MasRewardAd) {
      RewardHandler._sink?.invokeMethod("loaded_reward", arguments:ad.adPlacement)
    }
    public func onRewardAdFailed(toLoad ad: Yodo1MasRewardAd, withError error: Yodo1MasError) {
        ad.load()
        RewardHandler._sink?.invokeMethod("fail_load_reward", arguments:error.getJsonObject())
    }
    public func onRewardAdOpened(_ ad: Yodo1MasRewardAd) {
        RewardHandler._sink?.invokeMethod("open_reward", arguments:ad.adPlacement)
    }
    public func onRewardAdFailed(toOpen ad: Yodo1MasRewardAd, withError error: Yodo1MasError) {
        RewardHandler._sink?.invokeMethod("fail_open_reward", arguments:error.getJsonObject())
     }
    public func onRewardAdClosed(_ ad: Yodo1MasRewardAd) {
        ad.load()
        RewardHandler._sink?.invokeMethod("close_reward", arguments:ad.adPlacement)
     }
    public func onRewardAdEarned(_ ad: Yodo1MasRewardAd) {
        RewardHandler._sink?.invokeMethod("rewarded_reward", arguments:ad.adPlacement)
   }
}

// For Inter
extension YodosdkPlugin: Yodo1MasInterstitialDelegate {
    // MARK: Yodo1MasInterstitialDelegate
    public func onInterstitialAdLoaded(_ ad: Yodo1MasInterstitialAd) {
        print("Loaded")
        InterHandler._sink?.invokeMethod("loaded_inter", arguments:ad.adPlacement)
    }
    
    public func onInterstitialAdFailed(toLoad ad: Yodo1MasInterstitialAd, withError error: Yodo1MasError) {
        print("AdFailed")
        ad.load()
        InterHandler._sink?.invokeMethod("failed_load_inter",  arguments:ad.adPlacement)
    }
    
    public func onInterstitialAdOpened(_ ad: Yodo1MasInterstitialAd) {
        print("OnAd Open")
        InterHandler._sink?.invokeMethod("open_inter",  arguments:ad.adPlacement)
    }
    
    public func onInterstitialAdFailed(toOpen ad: Yodo1MasInterstitialAd, withError error: Yodo1MasError) {
       
        print("On Failed")
        InterHandler._sink?.invokeMethod("failed_open_inter",  arguments:ad.adPlacement)
    }
    
    public func onInterstitialAdClosed(_ ad: Yodo1MasInterstitialAd) {
        ad.load()
        print("On AdClose")
        InterHandler._sink?.invokeMethod("close_inter", arguments:  ad.adPlacement)
    }
    
}
